@@ -1,6 +1,6 @@
 <?php
 /**
- * $Id: action.defaultadmin.php 161 2011-01-29 16:41:10Z touchdesign $
+ * $Id: action.defaultadmin.php 166 2011-05-11 20:16:02Z touchdesign $
  *
  * touchInlineEdit Module
  *
@@ -8,7 +8,7 @@
  *
  * @category Module
  * @author Christoph Gruber <www.touchdesign.de>
- * @version 1.8.1
+ * @version 1.8.2
  * @copyright 2010 touchDesign
  * @link http://www.touchdesign.de/
  * @link http://www.homepage-community.de/index.php?topic=1680.0
@@ -38,7 +38,7 @@ if(!isset($gCms)){
   exit;
 }
 
-if(!$this->CheckPermission('Use touchInlineEdit')){
+if(!$this->CheckPermission('Modify touchInlineEdit Preferences')){
   echo $this->lang("nopermission");
   return;
 }
@@ -69,7 +69,9 @@ echo $this->StartTabHeaders();
 
 echo $this->SetTabHeader("settings",$this->Lang("settings"),($activeTab == 'settings' ? true : false));
 echo $this->SetTabHeader("permissions",$this->Lang("permissions"),($activeTab == 'permissions' ? true : false));
-echo $this->SetTabHeader("templates",$this->Lang("templates"),($activeTab == 'templates' ? true : false));
+if($this->CheckPermission('Modify Templates')){
+  echo $this->SetTabHeader("templates",$this->Lang("templates"),($activeTab == 'templates' ? true : false));
+}
 echo $this->SetTabHeader("editor",$this->Lang("editor"),($activeTab == 'editor' ? true : false));
 
 echo $this->EndTabHeaders();
