@@ -8,7 +8,7 @@
  *
  * @category Module
  * @author Christoph Gruber <www.touchdesign.de>
- * @version 1.8.1
+ * @version 1.8.2
  * @copyright 04.08.2010 touchDesign
  * @link http://www.touchdesign.de/
  * @link http://www.homepage-community.de/index.php?topic=1680.0
@@ -34,7 +34,7 @@
  *
  */
 
-if(!$this->CheckPermission('Modify Site Settings')){
+if(!$this->CheckPermission('Modify touchInlineEdit Preferences')){
   echo $this->lang("nopermission");
   return;
 }
