@@ -1,6 +1,6 @@
 <?php
 /**
- * $Id: action.savesettings.php 161 2011-01-29 16:41:10Z touchdesign $
+ * $Id: action.savesettings.php 169 2011-05-11 20:33:14Z touchdesign $
  *
  * touchInlineEdit Module
  *
@@ -8,7 +8,7 @@
  *
  * @category Module
  * @author Christoph Gruber <www.touchdesign.de>
- * @version 1.8.1
+ * @version 1.8.2
  * @copyright 04.08.2010 touchDesign
  * @link http://www.touchdesign.de/
  * @link http://www.homepage-community.de/index.php?topic=1680.0
@@ -34,7 +34,7 @@
  *
  */
 
-if(!$this->CheckPermission('Modify Site Settings')){
+if(!$this->CheckPermission('Modify touchInlineEdit Preferences')){
   echo $this->lang("nopermission");
   return;
 }
