@@ -8,7 +8,7 @@
  *
  * @category Module
  * @author Christoph Gruber <www.touchdesign.de>
- * @version 1.8.1
+ * @version 1.8.2
  * @copyright 04.08.2010 touchDesign
  * @link http://www.touchdesign.de/
  * @link http://www.homepage-community.de/index.php?topic=1680.0
@@ -81,7 +81,9 @@ if(version_compare($oldversion, '1.8.0', '<')){
   $this->SetPreference('touchInlineEdit.feUpdateAlertMessage', $this->Lang('feUpdateAlertMessage_default'));
   $this->AddEventHandler('Core', 'ContentPostRender', false);
 }
-
+if(version_compare($oldversion, '1.8.2', '<')){
+  $this->CreatePermission('Modify touchInlineEdit Preferences', 'Modify touchInlineEdit Preferences');
+}
 // Log upgrade info
 $this->Audit(0, $this->GetFriendlyName(), 
   $this->Lang('postupgrade', $this->GetVersion()));
